[manpage_begin spotoconf 1 0.92]
[moddesc   {Spotoconf}]
[titledesc {Configuration and build system}]
[category  {Programming tools}]
[copyright {2017,2018,2019,2022 Stuart Cassoff <stwo@users.sourceforge.net>}]
[keywords  configure build test install distribute]

[description]

	Spot o' Conf is a TEA-inspired configure and build system
	that caters to Tcl and Jim extensions.

[section {SETUP}]

	Copy all required files to the source dir of the package
	and create a spoto.conf file for the package. The spoto.conf
	file will be executed by configure and should set any
	variables required by the package.
[para]
	Building needs at minimum: configure, Makefile.in and a spoto.conf file for the package.
	Installing needs at minimum: Spotoconf/install-sh, LICENSE, README, README.licenses, README.configure.
[para]	
	Modify as needed; Spotoconf files are not auto-generated.

[section {Files}]

[list_begin definitions]
[def configure]
	Spotoconf's configure script.
[def Makefile.in]
	Spotoconf's Makefile.in. 
[def tclconfig/install-sh]

[def LICENSE]
[def spoto.conf]
	Package's spoto.conf
[def README]
[def Makefile.pkgs.in]
	Input Makefile for building a package that contains packages.
[def README.licenses]
[def README.configure]
[def doc]                      
[def tests/all.tcl]
	Test runner for use with tcltest.
[def tests2k/all.tcl]
	Test runner for use with tcltest2k.
[list_end]


[section {VARIABLES}]
	These are the variables that are substituted into output files.

[list_begin definitions]

[def FOR_WHAT]
	Tcl or Jim. Default is Tcl.
[def TITLE]
	Title of the package. Mixed case acceptable.
[def NAME]
	Name of the package. Should be lower case.
[def VERSION]
	Version of the package.
[def NAMESPACE]
	Namespace the package lives in.
[def PKG_NAME]

[def DIST_NAME]
[def DESCR]
	One line description of the package.
[def CATEGORIES]
	List of categories of the package.
[def HOMEPAGE]
	The home page of the package.
[def LICENSE]
	The license of the package.

[def LOAD_LIB]
	How to load libraries. Either load or source.
[def INIT]
	Name of init function for .so libs.

[def FOR_WHAT]
[def TITLE]
[def NAME]
[def VERSION]
[def NAMESPACE]
[def PKG_NAME]
[def DIST_NAME]

[def DESCR] One-sentence description.
[def CATEGORIES] Software categories.
[def HOMEPAGE] Software homepage.
[def LICENSE] Name of license

[def LIB]
[def SHLIB]
[def STLIB]
[def LIBOBJ]
[def LIBSRC]

[def SCLIB]
[def SCLIBSRC]
[def SCLIBSRCDIR]

[def DAT_DIR]
[def DAT_FILES]
[def DAT_SCRIPTS]

[def DOC]
[def DOCSRC]
[def DOCBLD]
[def DOCFMT]

[def EXA_FILES]
[def EXA_SCRIPTS]

[def SCBIN]
[def SCBINSRC]

[def PKGINDEX]
[def CFG_PKGINDEX]

[def LOAD_LIB]

[def INIT]

[def BIN]
[def BINOBJ]
[def BINSRC]

[def BUILD_DIR]

[def INSTALL]

[def INSTALL_LIB]
[def INSTALL_DOC]
[def INSTALL_EXA]
[def INSTALL_DAT]
[def INSTALL_BIN]
[def INSTALL_EXTRA]

[def PKG_INSTALL_DIR]
[def DOC_INSTALL_DIR]
[def DIST_INSTALL_DATA]
[def DIST_INSTALL_SCRIPT]

[def SH]
[def CC]
[def AR]
[def RANLIB]

[def CFLAGS_CC]
[def CFLAGS_WARN]
[def CFLAGS_OPT]
[def CFLAGS_DEBUG]
[def CFLAGS_BUILD]
[def CFLAGS_TH]

[def DEFS_TH]
[def DEFS_OPT]
[def DEFS_SPOT]
[def DEFS_TCL]
[def DEFS_JIM]
[def DEFS_TK]
[def DEFS]

[def LDFLAGS]
[def LDFLAGS_BUILD]

[def LIBS_TH]

[def EXT_CONF_FILES]
[def EXT_MK_FILES]
[def EXT_BUILD]
[def EXT_DEFS]
[def EXT_INC_SPEC]
[def EXT_LIB_SPEC]
[def EXT_DEP_FILES]

[def TCL_INC_SPEC]
[def TCL_LIB_SPEC]
[def TCL_STUB_LIB_SPEC]

[def JIM_INC_SPEC]
[def JIM_LIB_SPEC]

[def CC_INC_SPEC]
[def LD_LIB_SPEC]
[def TK_INC_SPEC]
[def TK_LIB_SPEC]
[def TK_STUB_LIB_SPEC]

[def LD_LIBRARY_PATH_VAR]
[def TCLLIBPATH]
[def TCL_TM_PATH]

[def JIMLIB]
[def TCLSH_PROG]
[def JIMSH_PROG]
[def BJE]

[def SHELL]

[def CLEAN]

[def DISTCLEAN]
[def DIST]

[def TEST]
[def TESTENV]
[def TESTFWK]
[def TESTFLAGS]
[def TESTFILES]

[def VPATH]

[def BUILDTYPE]
[def CROSS_COMPILE]

[def MAKE_SCLIB]
[def MAKE_SCBIN]
[def MAKE_DOC]

[def PKGS]
List of subpackages.

[def PKGS_DIR]
Subpackages dir. Default: 'pkgs'.

[def B]

[def README_SPOTOCONF]

[def cwd]
Current working directory as determinded by 'configure'.

[def srcdir]
Source dir path, possibly relative.

[def asrcdir]
Source dir path, absolute.

[def appdir]

[def prefix]
[def exec_prefix]

[def pkgdir]
[def moddir]
[def mandir]
[def docdir]
[def exadir]
[def datdir]
[def bindir]

[def SPOTO_ARGS]
Arguments passed to 'configure'.

[list_end]


[section {TARGETS}]

[section {GETTING FANCY}]

	Spotoconf can also determine a package's
	NAME, TITLE, VERSION, and one of LIB, BIN, or DAT
	from a fancy TITLE, LIB, BIN or DAT.

	The formula is name-version.extension.

	Ex. LIB=MyLib-1.2.tm will yield
	NAME=mylib
	TITLE=MyLib
	VERSION=1.2
	LIB=mylib-1.2.tm
	SCLIB=mylib-1.2.tm
	SCLIBSRC=mylib.tcl


[manpage_end]
